@@ -14,11 +14,9 @@
 """Database connection library."""
 import os
 
+import secret_manager
 import sqlalchemy
 
-from exit_speed.dashboard import instance_manager
-from exit_speed.dashboard import secret_manager
-
 # Local args used when running a development instance.
 # {'password': '',
 #  'username': '',
@@ -31,7 +29,6 @@ SECRET_LOCAL_ID = (
 
 def InitPool() -> sqlalchemy.engine.base.Engine:
   if os.getenv('GOOGLE_CLOUD_PROJECT'):
-    instance_manager.StartInstance()
     local_args = secret_manager.GetSecret(SECRET_LOCAL_ID)
     return sqlalchemy.create_engine(sqlalchemy.engine.url.URL(**local_args))
   return sqlalchemy.create_engine(sqlalchemy.engine.url.URL(
